sympy_code

Function sympy_code 

pub fn sympy_code(tree: &EmlTree) -> String
Generate a SymPy expression string for the tree.

The result uses SymPy’s exp / log and bare symbols x0, x1, …; it parses under from sympy import exp, log, symbols (with the xi declared as symbols) and can then be simplify-ed Python-side. The variables are listed in the doc comment of the emitted code.